@@ -12,7 +12,11 @@ use DateTime::Locale 0.4000;
 use DateTime::TimeZone;
 use Params::Validate qw( validate_pos validate SCALAR BOOLEAN OBJECT CODEREF );
 
-our $VERSION = '1.05';
+our @ISA = 'Exporter';
+our @EXPORT_OK = qw( &cldr_format &cldr_parse );
+our @EXPORT = ();
+
+our $VERSION = '1.06';
 
 # Simple regexp blocks
 our %PARTS = (
@@ -30,9 +34,9 @@ our %PARTS = (
     second      => qr/(6[01]|[0-5]?\d)/o,
     quarter     => qr/([1-4])/o,
     week_year   => qr/(5[0-3]|[1-4]\d|0?[1-9])/o,
-    week_month  => qr/\d/o,
-    timezone    => qr/[+-](1[0-4]|0?\d)(00|15|30|45)/o,
-    number      => qr/\d+/o,
+    week_month  => qr/(\d)/o,
+    #timezone    => qr/[+-](1[0-4]|0?\d)(00|15|30|45)/o,
+    number      => qr/(\d+)/o,
     timezone2   => qr/([A-Z1-9a-z])([+-](1[0-4]|0\d)(00|15|30|45))/o,
 );
 
@@ -198,7 +202,7 @@ our %PARSER = (
     m1      => $PARTS{minute},
     s1      => $PARTS{second},
     S1      => $PARTS{number},
-    Z1      => $PARTS{timezone},
+    Z1      => [ grep { $_ ne 'Ambiguous' } values %ZONEMAP ],
     Z4      => $PARTS{timezone2},
     z1      => [ keys %ZONEMAP ],
     z4      => [ DateTime::TimeZone->all_names ],
@@ -234,7 +238,7 @@ DateTime::Format::CLDR - Parse and format CLDR time patterns
         locale      => 'de_AT',
     );
     
-    # pattern is set to 'date_format_medium' from DateTime::Locale::de_AT
+    # pattern is taken from 'date_format_medium' in DateTime::Locale::de_AT
     my $dt = $cldr->parse_datetime('23.11.2007');
     
     # Croak when things go wrong:
@@ -329,6 +333,7 @@ sub new {
     $self->pattern($args{pattern});
     $self->on_error($args{on_error});
     $self->incomplete($args{incomplete});
+    $self->{errmsg} = undef;
     
     return $self;
 }
@@ -618,14 +623,15 @@ sub parse_datetime {
        
         # String
         } else {
-            return undef
+            return $self->_local_croak("Could not get datetime for $datetime_initial: $string")
                 unless ($string =~ s/$part//ix);
         }
         
         #print "BEFORE: '$before' AFTER: '$string' PATTERN: '$part'\n";
     }
     
-    
+    return $self->_local_croak("Could not get datetime for $datetime_initial: $string") 
+        if $string;
     
     # Fix 12 hour time notations
     if (defined $datetime_info{hour12} 
@@ -700,6 +706,57 @@ sub format_datetime {
     return $dt->format_cldr($self->{pattern});
 }
 
+
+=head3 errmsg
+
+ my $string = $cldr->errmsg();
+
+If the on_error behavior of the object is 'undef', error messages with this 
+method so you can work out why things went wrong.
+
+=cut
+
+sub errmsg {
+    $_[0]->{errmsg};
+}
+
+
+=head2 Exportable functions
+
+There are no methods exported by default, however the following are available:
+
+=head3 cldr_format
+
+ &cldr_format($pattern,$datetime);
+
+=cut
+
+sub cldr_format {
+    my ($pattern, $datetime) = @_;
+    
+    return $datetime->format_cldr($pattern);;
+}
+
+=head3 cldr_parse
+
+ &cldr_format($pattern,$string);
+ OR
+ &cldr_format($pattern,$string,$locale);
+
+=cut
+
+sub cldr_parse {
+    my ($pattern, $string, $locale) = @_;
+    
+    $locale ||= 'en';
+    return DateTime::Format::CLDR->new( 
+        pattern => $pattern,
+        locale  => $locale,
+        on_error=>'croak',
+    )->parse_datetime($string);
+}
+
+
 # ---------------------------------------------------------------------------
 # Private methods
 # ---------------------------------------------------------------------------
@@ -789,6 +846,8 @@ sub _build_pattern {
     return $self->{_built_pattern};
 }
 
+# Turn array into regexp
+
 sub _quoteslist {
     my ($list) = @_;
     return  
@@ -801,6 +860,8 @@ sub _quoteslist {
         ')';
 }
 
+# Quote regexp
+
 sub _quotestring {
     my ($quote) = @_;
    
@@ -834,12 +895,14 @@ sub _local_carp {
     
     warn($message) if $self->{on_error} eq 'croak';
     $self->{errmsg} = $message;
+    
     return undef if ($self->{on_error} eq 'undef');
     return;
 }
 
 
 
+
 1;
 
 =head1 CLDR PATTERNS
